@@ -73,7 +73,8 @@ cor_auto <- function(
 #     message("All variables detected to be continuous, computing nonparanormal skeptic!")
     
     for (i in seq_len(ncol(data))) data[,i] <- as.numeric(data[,i])
-    CorMat <- huge.npn(data, "skeptic")
+    if(!requireNamespace("huge")) stop("'huge' package needs to be installed.")
+    CorMat <- huge::huge.npn(data, "skeptic")
   } else {
     CorMat <- suppressWarnings( lavaan::lavCor(data, missing = missing) )
     class(CorMat) <- "matrix"
@@ -83,7 +84,7 @@ cor_auto <- function(
   if(forcePD & !all(eigen(CorMat)$values > 0))  {
     warning("Correlation matrix is not positive definite. Finding nearest positive definite matrix")
   
-    CorMat <- as.matrix(Matrix::nearPD(CorMat, corr = TRUE, ensureSymmetry = TRUE)$mat)
+    CorMat <- as.matrix(Matrix::nearPD(CorMat, corr = TRUE, ensureSymmetry = TRUE, keepDiag = TRUE)$mat)
   }
 
   return(CorMat)
@@ -124,4 +125,4 @@ cor_auto <- function(
 #   CorMat <- mutRes$COR
 #   attr(CorMat,"thresholds") <- mutRes$TH
 #   return(CorMat)
-}
\ No newline at end of file
+}
